=================
PyHyperScattering
=================

`PyHyperScattering <https://github.com/usnistgov/PyHyperScattering>`_ is a library for hyperspectral x-ray and neutron scattering data loading, reduction, slicing, and visualization. 

CyRSoXS Loader
________________

PyHyperScattering has a CyRSoXS-specific loader that will load a simulation into an xarray DataArray and allow you to use the same API to analyze your experimental and simulated RSoXSs data.

